<template>
  <el-bus-crud ref="curd" v-bind="tableConfig" />
</template>

<script>
import dayjs from 'dayjs'
import 'dayjs/locale/zh-cn'
import SelectAllUser from '@/components/sms/select-all-user'
import CopyTextarea from '@/components/sms/copy-textarea'
import TemplateDownload from '@/components/sms/template-download'
export default {
  data() {
    const defaultDate = `${dayjs().format('YYYY-MM-DD')} 00:00:00`
    return {
      tableConfig: {
        url: 'flower/v2/sms-task/list',
        newUrl: 'flower/v2/sms-task/new',
        editUrl: 'flower/v2/sms-task/edit',
        viewUrl: 'flower/v2/sms-task',
        viewOnPath: true,
        deleteUrl: 'flower/v2/sms-task/delete',
        hasNew: true,
        newText: '添加发送任务',
        dialogNeedRequest: true,
        canEdit: (row) => row.status === 'wait_publish',
        canDelete: (row) => row.status === 'wait_publish',
        extraButtons: [
          {
            text: '发布',
            show: (row) => {
              return row.status === 'wait_publish';
            },
            atClick: async (row) => {
              try {
                await this.$elBusUtil.confirm('确定要发布吗？')
                const { code } = await this.$elBusHttp.request(
                  `flower/v2/sms-task/publish`,
                  {
                    method: 'post',
                    data: {
                      id: row.id,
                    }
                  }
                )
                if (code === 0) {
                  this.$message.success('发布成功')
                }
              } catch (e) {
                return false
              }
            },
          },
        ],
        onResetView: (row) => {
          // this.$router.push(`${this.$route.path}/${row.id}`)

          // const searchFormRef = this.$refs.crud.$refs.searchForm
          // const searchFormValue = searchFormRef.getFormValue()
          const url = this.$router.resolve(
            `/sms/send-batch/${row.id}`
          ).href
          window.open(url, '_blank')

        },
        columns: [
          { label: '任务名称', prop: 'name' },
          { label: '模板名称', prop: 'smsTemplateName' },
          { label: '模板描述', prop: 'smsTemplateDesc' },
          { label: '任务状态', prop: 'statusStr' },
          { label: '创建时间', prop: 'createTime' },
        ],
        searchForm: [
          {
            type: 'row',
            items: [
              { label: '任务名称', id: 'name', type: 'input' },
              { label: '模板名称', id: 'smsTemplateName', type: 'input' },
              {
                label: '任务状态',
                id: 'status',
                type: 'bus-select-dict',
                el: {
                  code: 'SMS_TASK_STATUS',
                  multiple: false,
                  style: 'width:100%',
                },
              },
              {
                label: '创建时间',
                id: 'startDate',
                component: 'el-bus-date-range',
                el: {
                  clearable: true,
                },
                // commonFormat: true,
                // commonFormatProps: ['startDate', 'endDate'],
                inputFormat: (row) => {
                  if ('startDate' in row || 'endDate' in row) {
                    return [
                      this.$elBusUtil.toDate(row.startDate),
                      this.$elBusUtil.toDate(row.endDate),
                    ]
                  }
                },
                outputFormat: (val) => {
                  return {
                    startDate: val[0] ? `${this.$elBusUtil.toDate(val[0])} 00:00:00` : undefined,
                    endDate: val[1] ? `${this.$elBusUtil.toDate(val[1])} 23:59:59` : undefined,
                  }
                },
                customClass: 'in-bus-form',
                // commonRules: true,
                // default: [defaultDate, defaultDate],
              },

            ],
          },
        ],
        form: [
          {
            label: '任务名称',
            id: 'name',
            type: 'input',
            rules: {
              required: true,
              message: '请输入任务名称',
              trigger: 'blur',
            },
          },
          {
            label: '短信模板：',
            id: 'smsTemplateId',
            type: 'bus-select',
            el: {
              interfaceUri: 'flower/v2/sms-template/templateName/all',
              extraQuery: {
                current: 1,
                size: 2000,
              },
              props: {
                label: 'name',
                value: 'id',
                // dataPath: 'data',
              },
              filterable: true,
              multiple: false,
              style: 'width:100%',
            },
            rules: {
              required: true,
              message: '请选择短信模板',
              trigger: 'change',
            },
          },
          {
            label: '接收号码：',
            id: 'type',
            type: 'bus-radio',
            el: {
              code: 'SMS_RECEIVE_TYPE',
              // hasAll: false,
              // childType: 'el-radio-button',
            },
            str: true,
            on: {
              change: (e, updateForm, obj) => {
                // updateForm({
                //   // fileUrl: undefined,
                //   // fileUrlDesc: undefined,
                //   // pointCostomIdList: undefined,
                //   // input: undefined,
                // })
              },
            },
            default: this.$route.query.status || '',
            span: 24,
            searchImmediately: true,
            rules: {
              required: true,
              message: '请输入接收号码',
              trigger: 'change',
            },
          },
          {
            label: '导入接收文件',
            id: 'fileUrl',
            component: 'el-bus-upload',
            el: {
              // listType: 'text',
              accept: ".xls,.xlsx",
              limit: 1
            },
            commonFormat: true,
            forceDisabled: true,
            hidden: (row) => {
              return row.type !== 'IMPORT'
            },
            readonly: false,
            rules: [
              { required: true, message: '请上传文件' },
              {
                validator: (rule, value, callback) => {
                  if (!value || value.length > 1) {
                    callback(new Error('只能上传一个文件'));
                  } else {
                    callback();
                  }
                },
                trigger: 'change',
              },
            ],
          },
          {
            label: '',
            id: 'fileUrlDesc',
            component: TemplateDownload,
            hidden: (row) => row.type !== 'IMPORT',
          },
          {
            label: '手动输入：',
            id: 'phones',
            component: CopyTextarea,
            el: {
              type: 'textarea',
            },
            // hidden: (row) => row.discountType !== 'ratio',
            hidden: (row) => row.type !== 'INPUT',
            readonly: false,
            span: 24,
            rules: [
              { required: true, message: '请输入号码', trigger: 'blur,change', },
              // {
              //   validator: (rule, value, callback) => {
              //     // 如果值为空，直接返回错误
              //     if (!value || value.trim() === '') {
              //       callback(new Error('请输入电话号码，每个号码后跟换行符'));
              //       return;
              //     }

              //     // 正则表达式：只匹配中国大陆手机号格式
              //     const phoneRegex = /^1[3-9]\d{9}$/;
              //     const lines = value.split('\n'); // 按换行符分割文本

              //     // 遍历每一行并校验
              //     for (let i = 0; i < lines.length; i++) {
              //       const line = lines[i]; // 每一行去除空格
              //       if (line && !phoneRegex.test(line)) {
              //         // 如果当前行的电话号码格式不正确，提示出错的行号
              //         callback(new Error(`第 ${i + 1} 行电话号码格式不正确，请检查输入, 如 电话号码后面有空格等`));
              //         return; // 一旦发现不符合的号码格式，就终止校验
              //       }
              //     }

              //     if(lines.length>100){
              //       callback(new Error(`手动输入最多支持100个号码`));
              //     }

              //     // 所有行都符合格式，执行 callback()
              //     callback();
              //   },
              //   trigger: 'blur',
              // }
              {
                validator: (rule, value, callback) => {
                  // 如果值为空，直接返回错误
                  if (!value || value.trim() === '') {
                    callback(new Error('请输入电话号码，每个号码后跟换行符'));
                    return;
                  }



                  const phoneRegex = /^1[3-9]\d{9}$/; // 校验手机号格式
                  const lines = value.split('\n'); // 按换行符分割文本
                  const phoneCount = {}; // 用来统计电话号码出现次数

                  if (lines.length > 100) {
                    callback(new Error(`手动输入最多支持100个号码`));
                  }

                  // 校验每一行的电话号码
                  for (let i = 0; i < lines.length; i++) {
                    const line = lines[i].trim();
                    if (line) {
                      // 如果当前行不是空的，校验其格式
                      if (!phoneRegex.test(line)) {
                        callback(new Error(`第 ${i + 1} 行电话号码格式不正确，请检查输入`));
                        return;
                      }

                      // 统计号码出现的次数
                      phoneCount[line] = (phoneCount[line] || 0) + 1;
                    }
                  }


                  // 收集所有重复的电话号码
                  const duplicates = [];
                  for (const phone in phoneCount) {
                    if (phoneCount[phone] > 1) {
                      duplicates.push(`${phone} 重复了 ${phoneCount[phone]} 次`);
                    }
                  }


                  // 如果有重复号码，返回错误并列出所有重复的号码
                  if (duplicates.length > 0) {
                    callback(new Error(`以下电话号码重复：\n${duplicates.join('\n')}`));
                    return;
                  }

                  // 校验通过
                  callback();
                },
                trigger: 'blur',
              }

            ],

          },

          {
            label: '选择用户列表',
            id: 'smsUserDTOS',
            component: SelectAllUser,
            hidden: (row) => row.type !== 'SELECT',
            rules: { required: true, message: '请选择领取用户' },
            inputFormat: (row) => {
              if ('smsUserDTOS' in row) {
                return row.smsUserDTOS.filter((i) => i)
              }
            },
            outputFormat: (val) => {
              return val?.length ? val.map((i) => {return {userId:i.id,userPhone:i.tel} }) : []
            },
            forceDisabled: true,
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '批量发送短信',
    }
  },

}
</script>
